@@ -1,4 +1,5 @@
 """Constant values for the client."""
+
 from typing import Literal
 
 AUTHORIZATION_HEADER = "authorization"
@@ -9,9 +10,14 @@ ALLOWED_EXPAND_ATTRS = Literal[
     "take",
     "sources",
     "volume",
+    "rig",
+    "progress",
+    "clipWindow",
 ]
 CLIENT_LITERAL = "client"
 TAKE_LITERAL = "take"
 OUTPUTS_LITERAL = "outputs"
+INPUTS_LITERAL = "inputs"
 SOURCES_LITERAL = "sources"
 VOLUME_LITERAL = "volume"
+RIGS_LITERAL = "rig"
